# bucketstats

Data science tools for analyzing histograms using classic probbility theory and
statistics.  Useful when a dataset is too large to load into memory, but a
histogram is available.

[![Build Status](https://travis-ci.com/mprelee/bucketstats.svg?branch=master)](https://travis-ci.com/mprelee/bucketstats)
